==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ia.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentarios",
    "Unknown user" : "Usator incognite",
    "New comment …" : "Nove commentario ...",
    "Delete comment" : "Deler commentario",
    "Post" : "Publicar",
    "Cancel" : "Cancellar",
    "Edit comment" : "Modificar commentario",
    "[Deleted user]" : "[Usator delite]",
    "No comments yet, start the conversation!" : "Il ha nulle commentarios ancora, initia le conversation!",
    "More comments …" : "Plus commentarios ...",
    "Save" : "Salveguardar",
    "Allowed characters {count} of {max}" : "{count} characteres permittite de {max}",
    "Error occurred while retrieving comment with id {id}" : "Un error occurreva durante le recuperation del commentario identificate per {id}",
    "Error occurred while updating comment with id {id}" : "Un error occurreva durante le actualisation del commentario identificate per {id}",
    "Error occurred while posting comment" : "Un error occurreva durante le publication del commentario",
    "_%n unread comment_::_%n unread comments_" : ["%n commentario non legite","%n commentarios non legite"],
    "Comment" : "Commentario",
    "You commented" : "Tu commentava",
    "%1$s commented" : "%1$s commentava",
    "{author} commented" : "{author} commentava",
    "You commented on %1$s" : "Tu commentava in %1$s",
    "You commented on {file}" : "Tu commentava in {file}",
    "%1$s commented on %2$s" : "%1$s commentava in %2$s",
    "{author} commented on {file}" : "{author} commentava in {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentarios</strong> pro files",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un (ora) delite usator mentionava tu in un commentario in “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un (ora) delite usator mentionava tu in un commentario in “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentionava tu in un commentario in “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentionava tu in un commentario in “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ia.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentarios",
    "Unknown user" : "Usator incognite",
    "New comment …" : "Nove commentario ...",
    "Delete comment" : "Deler commentario",
    "Post" : "Publicar",
    "Cancel" : "Cancellar",
    "Edit comment" : "Modificar commentario",
    "[Deleted user]" : "[Usator delite]",
    "No comments yet, start the conversation!" : "Il ha nulle commentarios ancora, initia le conversation!",
    "More comments …" : "Plus commentarios ...",
    "Save" : "Salveguardar",
    "Allowed characters {count} of {max}" : "{count} characteres permittite de {max}",
    "Error occurred while retrieving comment with id {id}" : "Un error occurreva durante le recuperation del commentario identificate per {id}",
    "Error occurred while updating comment with id {id}" : "Un error occurreva durante le actualisation del commentario identificate per {id}",
    "Error occurred while posting comment" : "Un error occurreva durante le publication del commentario",
    "_%n unread comment_::_%n unread comments_" : ["%n commentario non legite","%n commentarios non legite"],
    "Comment" : "Commentario",
    "You commented" : "Tu commentava",
    "%1$s commented" : "%1$s commentava",
    "{author} commented" : "{author} commentava",
    "You commented on %1$s" : "Tu commentava in %1$s",
    "You commented on {file}" : "Tu commentava in {file}",
    "%1$s commented on %2$s" : "%1$s commentava in %2$s",
    "{author} commented on {file}" : "{author} commentava in {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentarios</strong> pro files",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentionava tu in un commentario in “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentionava tu in un commentario in “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un (ora) delite usator mentionava tu in un commentario in “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un (ora) delite usator mentionava tu in un commentario in “{file}”"
},
"nplurals=2; plural=(n != 1);");
